==> razorqt_0.4.1.orig.tar.xz: razorqt-0.4.1/razorqt-panel/plugin-mount/translations/mount_da_DK.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="da_DK">
<context>
    <name>MenuDiskItem</name>
    <message>
        <location filename="../menudiskitem.ui" line="44"/>
        <source>Click to access this device from other applications.</source>
        <translation>Klik for at give adgang fra andre programmer.</translation>
    </message>
    <message>
        <location filename="../menudiskitem.ui" line="54"/>
        <source>Click to eject this disc.</source>
        <translation>Skub ud.</translation>
    </message>
</context>
<context>
    <name>MountButton</name>
    <message>
        <location filename="../mountbutton.cpp" line="149"/>
        <source>Removable media/devices manager</source>
        <translation>Håndtering af flytbare medier</translation>
    </message>
    <message>
        <location filename="../mountbutton.cpp" line="187"/>
        <source>The device &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; is connected.</source>
        <translation>Enheden &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; er forbundet.</translation>
    </message>
    <message>
        <location filename="../mountbutton.cpp" line="205"/>
        <source>The device &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; is removed.</source>
        <translation>Enheden &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; er fjernet.</translation>
    </message>
    <message>
        <location filename="../mountbutton.cpp" line="233"/>
        <source>No devices Available.</source>
        <translation>Ingen enheder tilgængelige.</translation>
    </message>
</context>
<context>
    <name>RazorMountConfiguration</name>
    <message>
        <location filename="../razormountconfiguration.ui" line="14"/>
        <source>Razor Removable media manager settings</source>
        <translation>Indstillinger til håndtering af flytbare enheder</translation>
    </message>
    <message>
        <location filename="../razormountconfiguration.ui" line="20"/>
        <source>Behaviour</source>
        <translation>Adfærd</translation>
    </message>
    <message>
        <location filename="../razormountconfiguration.ui" line="26"/>
        <source>When a device is connected </source>
        <translation>Når en enhed tilsluttes </translation>
    </message>
    <message>
        <location filename="../razormountconfiguration.cpp" line="44"/>
        <source>Popup menu</source>
        <translation>Popup menu</translation>
    </message>
    <message>
        <location filename="../razormountconfiguration.cpp" line="45"/>
        <source>Show info</source>
        <translation>Vis info</translation>
    </message>
    <message>
        <location filename="../razormountconfiguration.cpp" line="46"/>
        <source>Do nothing</source>
        <translation>Gør ingenting</translation>
    </message>
</context>
</TS>

==> razorqt_0.5.2.orig.tar.xz: razorqt-0.5.2/razorqt-panel/plugin-mount/translations/mount_da_DK.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="da_DK" version="2.0">
<context>
    <name>MenuDiskItem</name>
    <message>
        <source>Click to access this device from other applications.</source>
        <translation>Klik for at give adgang fra andre programmer.</translation>
    </message>
    <message>
        <source>Click to eject this disc.</source>
        <translation>Skub ud.</translation>
    </message>
</context>
<context>
    <name>MountButton</name>
    <message>
        <source>Removable media/devices manager</source>
        <translation>Håndtering af flytbare medier</translation>
    </message>
    <message>
        <source>The device &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; is connected.</source>
        <translation>Enheden &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; er forbundet.</translation>
    </message>
    <message>
        <source>The device &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; is removed.</source>
        <translation>Enheden &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; er fjernet.</translation>
    </message>
</context>
<context>
    <name>Popup</name>
    <message>
        <source>No devices are available</source>
        <translation>Ingen enheder er tilgængelige
</translation>
    </message>
</context>
<context>
    <name>RazorMountConfiguration</name>
    <message>
        <source>Razor Removable media manager settings</source>
        <translation>Indstillinger til håndtering af flytbare enheder</translation>
    </message>
    <message>
        <source>Behaviour</source>
        <translation>Adfærd</translation>
    </message>
    <message>
        <source>When a device is connected </source>
        <translation>Når en enhed tilsluttes </translation>
    </message>
    <message>
        <source>Popup menu</source>
        <translation>Popup menu</translation>
    </message>
    <message>
        <source>Show info</source>
        <translation>Vis info</translation>
    </message>
    <message>
        <source>Do nothing</source>
        <translation>Gør ingenting</translation>
    </message>
</context>
</TS>
